@@ -206,6 +206,13 @@ class CompositePKFilterTests(TestCase):
             [self.comment_1],
         )
 
+    def test_filter_by_pk_in_none(self):
+        with self.assertNumQueries(0):
+            self.assertSequenceEqual(
+                Comment.objects.filter(pk__in=[(None, 1), (1, None)]),
+                [],
+            )
+
     def test_filter_comments_by_user_and_order_by_pk_asc(self):
         self.assertSequenceEqual(
             Comment.objects.filter(user=self.user_1).order_by("pk"),
